PCB Environment: /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/UI/BrowserTab.hpp Source File

PCB Environment 2

Loading...
Searching...
No Matches
BrowserTab.hpp
1
2#ifndef GYM_PCB_UI_BROWSERTAB_H
3#define GYM_PCB_UI_BROWSERTAB_H
4
5#include "Py.hpp"
6#include <QWidget>
7class QTreeView;
8
9class GLWidget;
10class PCBoard;
11
12 class BrowserTab : public QWidget
13{
14 Q_OBJECT
15public:
16 void connect(GLWidget &GLW) { mWidget = &GLW; }
17 void init();
18 void setBoard(const PCBoard *);
19private slots:
20 void onClickItem(const QModelIndex&);
21private:
22 QTreeView *mTreeView;
23 GLWidget *mWidget{0};
24};
25
26#endif // GYM_PCB_UI_BROWSERTAB_H
BrowserTab
Definition BrowserTab.hpp:13
GLWidget
Definition GLWidget.hpp:34
PCBoard
Definition PCBoard.hpp:36